PN: init-system-helpers
PV: 1.66
PR: r0
PKGV: 1.66
PKGR: r0@EXTENDPRAUTO@
LICENSE: BSD-3-Clause & GPL-2.0-only
DESCRIPTION: This package contains helper tools that are necessary for switching between the various init systems that Debian contains (e. g. sysvinit or systemd). An example is deb-systemd-helper, a script that enables systemd unit files without depending on a running systemd. It also includes the \\"service\\", \\"invoke-rc.d\\", and \\"update-rc.d\\" scripts which provide an abstraction for enabling, disabling, starting, and stopping services for all supported Debian init systems as specified by the policy. While this package is maintained by pkg-systemd-maintainers, it is NOT specific to systemd at all. Maintainers of other init systems are welcome to include their helpers in this package.
SUMMARY: helper tools for all init systems
SECTION: base
PKG:init-system-helpers-invoke-rc.d: init-system-helpers-invoke-rc.d
FILES:init-system-helpers-invoke-rc.d: /usr/sbin/invoke-rc.d
FILES_INFO:init-system-helpers-invoke-rc.d: {"/usr/sbin/invoke-rc.d": 16517}
FILERDEPENDSFLIST:init-system-helpers-invoke-rc.d: /usr/sbin/invoke-rc.d
FILERDEPENDS:/usr/sbin/invoke-rc.d:init-system-helpers-invoke-rc.d:  /bin/sh
PKGSIZE:init-system-helpers-invoke-rc.d: 16517
